mq

package
v0.0.0-...-6ba8834 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 12, 2014 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Channel

func Channel() <-chan interface{}

Channel returns a new channed into which all received data will be sent

func Send

func Send(data interface{})

Send data to any listening receivers If the receivers buffered channel is full, the events are dropped

Types

type ChannelReader

type ChannelReader struct {
	Out <-chan []interface{}
	// contains filtered or unexported fields
}

ChannelReader reads available input into chunks

func NewChannelReader

func NewChannelReader(ch <-chan interface{}, maxSize int) *ChannelReader

NewChannelReader initializes a new reader maximum sizes of less than two result in an effective maximum size of two

func (*ChannelReader) Read

func (r *ChannelReader) Read() []interface{}

Read infinitely drains available input into buffers which are passed into the output channel

Jump to