Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ChannelReader ¶
type ChannelReader struct {
Out <-chan []interface{}
// contains filtered or unexported fields
}
ChannelReader reads available input into chunks
func NewChannelReader ¶
func NewChannelReader(ch <-chan interface{}, maxSize int) *ChannelReader
NewChannelReader initializes a new reader maximum sizes of less than two result in an effective maximum size of two
func (*ChannelReader) Read ¶
func (r *ChannelReader) Read() []interface{}
Read infinitely drains available input into buffers which are passed into the output channel
Click to show internal directories.
Click to hide internal directories.